@@ -1,6 +1,10 @@
-use actix_web::ResponseError;
 use thiserror::Error;
 
+#[cfg(not(feature = "actix-web-v4"))]
+use actix_web_3::ResponseError;
+#[cfg(feature = "actix-web-v4")]
+use actix_web_4::ResponseError;
+
 /// An error that occurred while providing a location.
 #[derive(Error, Debug)]
 #[allow(missing_docs)]
